@@ -1,6 +1,8 @@
 context("re_matches")
-df2 = function(...) { data.frame(..., stringsAsFactors = FALSE, check.names = FALSE) }
-string = c("this is Text", "chr-12", "12343 66544456")
+df2 <- function(...) {
+  data.frame(..., stringsAsFactors = FALSE, check.names = FALSE)
+}
+string <- c("this is Text", "chr-12", "12343 66544456")
 
 test_that("re_matches if given other than character vector", {
 
@@ -32,14 +34,14 @@ test_that("re_matches capture returns a data frame", {
 
 test_that("re_matches with global returns a list of matches", {
 
-  # Global without captures doesn't make a ton of sense but lets test it anyway
-  expect_equal(re_matches(string, rex('is'), global = TRUE),
+  # Global without captures doesn"t make a ton of sense but lets test it anyway
+  expect_equal(re_matches(string, rex("is"), global = TRUE),
     list(c(TRUE, TRUE), FALSE, FALSE))
 })
 
 test_that("re_matches with global returns a list of data.frames", {
 
-  expect_equal(re_matches(string, rex(capture(any_letters, 'is')), global = TRUE),
+  expect_equal(re_matches(string, rex(capture(any_letters, "is")), global = TRUE),
     list(df2(`1` = c("this", "is")), df2(`1` = NA_character_), df2(`1` = NA_character_)) )
   expect_equal(re_matches(string, rex(capture(digits, name = "number")), global = TRUE),
     list(df2("number" = NA_character_), df2("number" = "12"), df2("number" = c("12343", "66544456"))))
@@ -54,7 +56,7 @@ test_that("re_matches named capture returns named data frame", {
 })
 
 test_that("examples are correct", {
-string = c("this is a", "test string")
+string <- c("this is a", "test string")
 expect_equal(re_matches(string, rex(capture(alphas, name = "first_word"), space,
                 capture(alphas, name = "second_word"))),
             df2(first_word = c("this", "test"),
@@ -120,7 +122,7 @@ test_that("re_matches named capture returns named data frame", {
 
 test_that("re_matches with global returns a list of matches", {
 
-  expect_equal(re_matches(string, rex('is'), global = TRUE, locations = TRUE),
+  expect_equal(re_matches(string, rex("is"), global = TRUE, locations = TRUE),
     list(
       df2(start = c(3L, 6L), end = c(4L, 7L)),
       df2(start = NA_integer_, end = NA_integer_),
@@ -131,7 +133,7 @@ test_that("re_matches with global returns a list of matches", {
 
 test_that("re_matches with global returns a list of data.frames", {
 
-  expect_equal(re_matches(string, rex(capture(any_letters, 'is')), global = TRUE, locations = TRUE),
+  expect_equal(re_matches(string, rex(capture(any_letters, "is")), global = TRUE, locations = TRUE),
     list(
       df2("1.start" = c(1L, 6L), "1.end" = c(4L, 7L)),
       df2("1.start" = NA_integer_, "1.end" = NA_integer_),
@@ -149,7 +151,7 @@ test_that("re_matches with global returns a list of data.frames", {
 })
 
 test_that("examples are correct", {
-string = c("this is a", "test string")
+string <- c("this is a", "test string")
 expect_equal(re_matches(string, rex(capture(alphas, name = "first_word"), space,
                 capture(alphas, name = "second_word"))),
             df2(first_word = c("this", "test"),
@@ -161,12 +163,12 @@ expect_equal(re_matches(string, rex(capture("test"))),
 
 context("re_substitutes")
 test_that("s substitutes properly, with and without options", {
-  expect_equal(re_substitutes(string, rex('Text'), 'test'),
-    c('this is test', 'chr-12', '12343 66544456'))
+  expect_equal(re_substitutes(string, rex("Text"), "test"),
+    c("this is test", "chr-12", "12343 66544456"))
 
-  expect_equal(re_substitutes(string, rex('text'), 'test', options='insensitive'),
-    c('this is test', 'chr-12', '12343 66544456'))
+  expect_equal(re_substitutes(string, rex("text"), "test", options="insensitive"),
+    c("this is test", "chr-12", "12343 66544456"))
 
-  expect_equal(re_substitutes(string, 'i', 'x', global = TRUE),
-    c('thxs xs Text', 'chr-12', '12343 66544456'))
+  expect_equal(re_substitutes(string, "i", "x", global = TRUE),
+    c("thxs xs Text", "chr-12", "12343 66544456"))
 })
